@@ -118,6 +118,29 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CheckCertificateDomainVerification(self, request):
+        """检查证书域名验证
+
+        :param request: Request instance for CheckCertificateDomainVerification.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CheckCertificateDomainVerificationRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CheckCertificateDomainVerificationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckCertificateDomainVerification", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckCertificateDomainVerificationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CommitCertificateInformation(self, request):
         """提交证书订单。
 
@@ -188,7 +211,7 @@ class SslClient(AbstractClient):
 
 
     def CreateCertificateBindResourceSyncTask(self, request):
-        """创建证书绑定关联云资源异步任务， 该接口用于查询证书关联云资源。 若证书ID已存在查询云资源任务，则结果返回该任务ID。关联云资源类型，支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）。查询关联云资源结果使用DescribeCertificateBindResourceTaskResult接口
+        """创建证书绑定关联云资源异步任务， 该接口用于查询证书关联云资源。 若证书ID已存在查询云资源任务，则结果返回该任务ID。关联云资源类型，支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）、cos。查询关联云资源结果使用DescribeCertificateBindResourceTaskResult接口
 
         :param request: Request instance for CreateCertificateBindResourceSyncTask.
         :type request: :class:`tencentcloud.ssl.v20191205.models.CreateCertificateBindResourceSyncTaskRequest`
@@ -256,6 +279,29 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteCertificates(self, request):
+        """批量删除证书，删除证书前支持查询证书是否关联了腾讯云云资源 （需自定义配置参数，参数名称：IsSync）
+
+        :param request: Request instance for DeleteCertificates.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DeleteCertificatesRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DeleteCertificatesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteCertificates", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteCertificatesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteManager(self, request):
         """删除管理人
 
@@ -372,7 +418,7 @@ class SslClient(AbstractClient):
 
 
     def DescribeCertificateBindResourceTaskDetail(self, request):
-        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）
+        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）、cos
 
         :param request: Request instance for DescribeCertificateBindResourceTaskDetail.
         :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeCertificateBindResourceTaskDetailRequest`
@@ -395,7 +441,7 @@ class SslClient(AbstractClient):
 
 
     def DescribeCertificateBindResourceTaskResult(self, request):
-        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）
+        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）、cos
 
         :param request: Request instance for DescribeCertificateBindResourceTaskResult.
         :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeCertificateBindResourceTaskResultRequest`
